@@ -111,19 +111,29 @@ save_through_plain_persist_stream (const gchar *filename,
 
 	CORBA_exception_init (&ev);
 
-	/* FIX2 stream = bonobo_stream_open (BONOBO_IO_DRIVER_FS, filename,
-				     Bonobo_Storage_WRITE |
-				     Bonobo_Storage_CREATE |
-				     Bonobo_Storage_FAILIFEXIST, 0); */
+	stream = bonobo_stream_mem_create (NULL, 0, FALSE, TRUE);
 
 	if (stream == NULL) {
 		g_warning ("Couldn't create `%s'\n", filename);
 	} else {
 		Bonobo_Stream corba_stream;
+		BonoboStreamMem *stream_mem;
+		GByteArray *text;
+		int fd;
 
 		corba_stream = bonobo_object_corba_objref (stream);
 		Bonobo_Stream_truncate (corba_stream, 0, &ev);
 		Bonobo_PersistStream_save (pstream, corba_stream, "text/plain", &ev);
+
+		stream_mem = BONOBO_STREAM_MEM (stream);
+		text = g_byte_array_new ();
+		g_byte_array_append (text, stream_mem->buffer, stream_mem->pos);
+		bonobo_object_unref (BONOBO_OBJECT (stream));
+
+		fd = creat (filename, 0622);
+		write (fd, text->data, text->len);
+		close (fd);
+		g_byte_array_free (text, TRUE);
 	}
 
 	Bonobo_Unknown_unref (pstream, &ev);
@@ -247,6 +257,12 @@ view_html_source_html_cb (GtkWidget *widget,
 	view_source_dialog (data, "text/html", TRUE);
 }
 
+static void
+file_selection_cancel_cb (GtkWidget *widget, gpointer data)
+{
+	gtk_widget_destroy (GTK_WIDGET (data));
+}
+
 static void
 file_selection_ok_cb (GtkWidget *widget,
 		      gpointer data)
@@ -270,7 +286,7 @@ file_selection_ok_cb (GtkWidget *widget,
 		g_warning ("The Control does not seem to support `%s'.", interface_name);
 	} else 	 {
 		const gchar *fname;
-	
+
 		fname = gtk_file_selection_get_filename
 			(GTK_FILE_SELECTION (file_selection_info.widget));
 
@@ -325,8 +341,7 @@ open_or_save_as_dialog (BonoboWindow *app,
 	file_selection_info.control = control;
 	file_selection_info.operation = op;
 
-	g_signal_connect_object (GTK_FILE_SELECTION (widget)->cancel_button,
-				 "clicked", G_CALLBACK (gtk_widget_destroy), widget, G_CONNECT_AFTER);
+	g_signal_connect (GTK_FILE_SELECTION (widget)->cancel_button, "clicked", G_CALLBACK (file_selection_cancel_cb), widget);
 	g_signal_connect (GTK_FILE_SELECTION (widget)->ok_button, "clicked", G_CALLBACK (file_selection_ok_cb), NULL);
 	g_signal_connect (file_selection_info.widget, "destroy", G_CALLBACK (file_selection_destroy_cb), NULL);
 
@@ -511,6 +526,17 @@ container_create (void)
 	bonobo_object_release_unref (engine, &ev);
 	CORBA_exception_free (&ev);
 
+	bonobo_widget_set_property (BONOBO_WIDGET (control),
+				    "MagicSmileys", TC_CORBA_boolean, TRUE,
+				    NULL);
+	bonobo_widget_set_property (BONOBO_WIDGET (control),
+				    "MagicLinks", TC_CORBA_boolean, TRUE,
+				    NULL);
+	bonobo_widget_set_property (BONOBO_WIDGET (control),
+				   "InlineSpelling", TC_CORBA_boolean, TRUE,
+				   NULL);
+
+
 	return FALSE;
 }
 
