@@ -35,9 +35,6 @@ struct _HTMLIFrame {
 	GtkWidget *scroll;
 	GtkWidget *html;
 	HTMLPainter *gdk_painter;
-	HTMLPainter *old_painter;
-	HTMLPainter *parent_painter;
-
 	gint width;
 	gint height;
 	gboolean frameborder;
@@ -68,6 +65,11 @@ HTMLObject *   html_iframe_new                   (GtkWidget *parent,
 						  gboolean border);
 
 void           html_iframe_set_scrolling         (HTMLIFrame *iframe, GtkPolicyType scroll);
+
+void           html_iframe_set_margin_width      (HTMLIFrame *iframe,
+						 gint margin);
+void           html_iframe_set_margin_height     (HTMLIFrame *iframe,
+						 gint margin);
 						  
 #endif
 
