@@ -72,6 +72,8 @@ struct _HTMLObject {
 
 	GData *object_data;
 	GData *object_data_nocp;
+
+	char *id;
 };
 
 struct _HTMLObjectClearRectangle {
@@ -595,6 +597,7 @@ HTMLObject *html_object_next_cursor_leaf    (HTMLObject *o,
 HTMLObject *html_object_prev_cursor_leaf    (HTMLObject *o,
 					     HTMLEngine *e);
 
-HTMLClueFlow * html_object_get_flow (HTMLObject *o);
-
+const char *html_object_get_id  (HTMLObject *o);
+void        html_object_set_id  (HTMLObject *o,
+				 const char *id);
 #endif /* _HTMLOBJECT_H_ */
